==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/CreateVoiceTemplateRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class CreateVoiceTemplateRequest(
    templateName: __string,
    voiceTemplateRequest: zio.aws.pinpoint.model.VoiceTemplateRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest = {
    import CreateVoiceTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
      .builder()
      .templateName(__string.unwrap(templateName): java.lang.String)
      .voiceTemplateRequest(voiceTemplateRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.CreateVoiceTemplateRequest.ReadOnly =
    zio.aws.pinpoint.model.CreateVoiceTemplateRequest.wrap(buildAwsValue())
}
object CreateVoiceTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.CreateVoiceTemplateRequest =
      zio.aws.pinpoint.model.CreateVoiceTemplateRequest(
        templateName,
        voiceTemplateRequest.asEditable
      )
    def templateName: __string
    def voiceTemplateRequest
        : zio.aws.pinpoint.model.VoiceTemplateRequest.ReadOnly
    def getTemplateName: ZIO[Any, Nothing, __string] = ZIO.succeed(templateName)
    def getVoiceTemplateRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.VoiceTemplateRequest.ReadOnly
    ] = ZIO.succeed(voiceTemplateRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
  ) extends zio.aws.pinpoint.model.CreateVoiceTemplateRequest.ReadOnly {
    override val templateName: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.templateName())
    override val voiceTemplateRequest
        : zio.aws.pinpoint.model.VoiceTemplateRequest.ReadOnly =
      zio.aws.pinpoint.model.VoiceTemplateRequest
        .wrap(impl.voiceTemplateRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
  ): zio.aws.pinpoint.model.CreateVoiceTemplateRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/CreateVoiceTemplateRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class CreateVoiceTemplateRequest(
    templateName: __string,
    voiceTemplateRequest: zio.aws.pinpoint.model.VoiceTemplateRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest = {
    import CreateVoiceTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
      .builder()
      .templateName(templateName: java.lang.String)
      .voiceTemplateRequest(voiceTemplateRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.CreateVoiceTemplateRequest.ReadOnly =
    zio.aws.pinpoint.model.CreateVoiceTemplateRequest.wrap(buildAwsValue())
}
object CreateVoiceTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.CreateVoiceTemplateRequest =
      zio.aws.pinpoint.model.CreateVoiceTemplateRequest(
        templateName,
        voiceTemplateRequest.asEditable
      )
    def templateName: __string
    def voiceTemplateRequest
        : zio.aws.pinpoint.model.VoiceTemplateRequest.ReadOnly
    def getTemplateName: ZIO[Any, Nothing, __string] = ZIO.succeed(templateName)
    def getVoiceTemplateRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.VoiceTemplateRequest.ReadOnly
    ] = ZIO.succeed(voiceTemplateRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
  ) extends zio.aws.pinpoint.model.CreateVoiceTemplateRequest.ReadOnly {
    override val templateName: __string = impl.templateName(): __string
    override val voiceTemplateRequest
        : zio.aws.pinpoint.model.VoiceTemplateRequest.ReadOnly =
      zio.aws.pinpoint.model.VoiceTemplateRequest
        .wrap(impl.voiceTemplateRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateVoiceTemplateRequest
  ): zio.aws.pinpoint.model.CreateVoiceTemplateRequest.ReadOnly = new Wrapper(
    impl
  )
}
